==> flink-table-store-0.2.0-src.tgz: flink-table-store-0.2.0/flink-table-store-core/src/main/java/org/apache/flink/table/store/table/sink/FileCommittable.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.flink.table.store.table.sink;

import org.apache.flink.table.data.binary.BinaryRowData;
import org.apache.flink.table.store.file.mergetree.Increment;

import java.util.Objects;

/** File committable for sink. */
public class FileCommittable {

    private final BinaryRowData partition;

    private final int bucket;

    private final Increment increment;

    public FileCommittable(BinaryRowData partition, int bucket, Increment increment) {
        this.partition = partition;
        this.bucket = bucket;
        this.increment = increment;
    }

    public BinaryRowData partition() {
        return partition;
    }

    public int bucket() {
        return bucket;
    }

    public Increment increment() {
        return increment;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        FileCommittable that = (FileCommittable) o;
        return bucket == that.bucket
                && Objects.equals(partition, that.partition)
                && Objects.equals(increment, that.increment);
    }

    @Override
    public int hashCode() {
        return Objects.hash(partition, bucket, increment);
    }
}

==> flink-table-store-0.2.1-src.tgz: flink-table-store-0.2.1/flink-table-store-core/src/main/java/org/apache/flink/table/store/table/sink/FileCommittable.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.flink.table.store.table.sink;

import org.apache.flink.table.data.binary.BinaryRowData;
import org.apache.flink.table.store.file.mergetree.Increment;

import java.util.Objects;

/** File committable for sink. */
public class FileCommittable {

    private final BinaryRowData partition;

    private final int bucket;

    private final Increment increment;

    public FileCommittable(BinaryRowData partition, int bucket, Increment increment) {
        this.partition = partition;
        this.bucket = bucket;
        this.increment = increment;
    }

    public BinaryRowData partition() {
        return partition;
    }

    public int bucket() {
        return bucket;
    }

    public Increment increment() {
        return increment;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        FileCommittable that = (FileCommittable) o;
        return bucket == that.bucket
                && Objects.equals(partition, that.partition)
                && Objects.equals(increment, that.increment);
    }

    @Override
    public int hashCode() {
        return Objects.hash(partition, bucket, increment);
    }

    @Override
    public String toString() {
        return "FileCommittable{"
                + "partition="
                + partition
                + ", bucket="
                + bucket
                + ", increment="
                + increment
                + '}';
    }
}
